==> sign-center-api-0.2.27-006-sources.jar: cn/com/duiba/sign/center/api/util/SignActTypeUtil.java <==
package cn.com.duiba.sign.center.api.util;

import cn.com.duiba.activity.common.center.api.enums.share.ShareRelTypeEnum;
import cn.com.duiba.api.enums.ActivityUniformityTypeEnum;
import cn.com.duiba.sign.center.api.enums.creditssign.SignActivityTypeEnum;
import cn.com.duiba.sign.center.api.enums.creditssign.SignSourceTypeEnum;

import java.util.HashMap;
import java.util.Map;

/**
 * Created by xiaoxuda on 2019/3/18.
 */
public class SignActTypeUtil {
    private static Map<SignSourceTypeEnum, SignActivityTypeEnum> sourceToActType = new HashMap<>();
    private static Map<SignActivityTypeEnum, SignSourceTypeEnum> actTypeToSource = new HashMap<>();
    private static Map<SignActivityTypeEnum, ActivityUniformityTypeEnum> actTypeToUniform = new HashMap<>();
    private static Map<ShareRelTypeEnum, SignActivityTypeEnum> ShareActTypeToActType = new HashMap<>();
    static{
        sourceToActType.put(SignSourceTypeEnum.SIGN_SYSTEM, SignActivityTypeEnum.SIGN_CALENDAR);
        sourceToActType.put(SignSourceTypeEnum.SIGN_FOR_NEW, SignActivityTypeEnum.SIGN_FOR_NEW);
        ShareActTypeToActType.put(ShareRelTypeEnum.SIGN_FOR_NEW,SignActivityTypeEnum.SIGN_FOR_NEW);
        for(Map.Entry<SignSourceTypeEnum, SignActivityTypeEnum> entry : sourceToActType.entrySet()){
            actTypeToSource.put(entry.getValue(), entry.getKey());
        }

        actTypeToUniform.put(SignActivityTypeEnum.SIGN_CALENDAR, ActivityUniformityTypeEnum.CalendarSign);
        actTypeToUniform.put(SignActivityTypeEnum.SIGN_CONTRACT, ActivityUniformityTypeEnum.ContractSign);
        actTypeToUniform.put(SignActivityTypeEnum.SIGN_FOR_NEW, ActivityUniformityTypeEnum.SignForNew);
    }

    public static SignActivityTypeEnum getSignActType(SignSourceTypeEnum sourceType){
        return sourceToActType.get(sourceType);
    }

    public static SignSourceTypeEnum getSignSource(SignActivityTypeEnum signType){
        return actTypeToSource.get(signType);
    }

    public static ActivityUniformityTypeEnum getUniActType(SignActivityTypeEnum signType){
        return actTypeToUniform.get(signType);
    }

    public static SignActivityTypeEnum getSignActTypeByShareTypeEnum(ShareRelTypeEnum shareRelTypeEnum){
        return ShareActTypeToActType.get(shareRelTypeEnum);
    }
}

==> sign-center-api-0.3.35-20210617.110238-2-sources.jar: cn/com/duiba/sign/center/api/util/SignActTypeUtil.java <==
package cn.com.duiba.sign.center.api.util;

import cn.com.duiba.activity.common.center.api.enums.share.ShareRelTypeEnum;
import cn.com.duiba.api.enums.ActivityUniformityTypeEnum;
import cn.com.duiba.sign.center.api.enums.creditssign.SignActivityTypeEnum;
import cn.com.duiba.sign.center.api.enums.creditssign.SignSourceTypeEnum;

import java.util.HashMap;
import java.util.Map;

/**
 * Created by xiaoxuda on 2019/3/18.
 */
public class SignActTypeUtil {

    private SignActTypeUtil(){}

    private static Map<SignSourceTypeEnum, SignActivityTypeEnum> sourceToActType = new HashMap<>();
    private static Map<SignActivityTypeEnum, SignSourceTypeEnum> actTypeToSource = new HashMap<>();
    private static Map<SignActivityTypeEnum, ActivityUniformityTypeEnum> actTypeToUniform = new HashMap<>();
    private static Map<ShareRelTypeEnum, SignActivityTypeEnum> ShareActTypeToActType = new HashMap<>();
    static{
        sourceToActType.put(SignSourceTypeEnum.SIGN_SYSTEM, SignActivityTypeEnum.SIGN_CALENDAR);
        sourceToActType.put(SignSourceTypeEnum.SIGN_FOR_NEW, SignActivityTypeEnum.SIGN_FOR_NEW);
        sourceToActType.put(SignSourceTypeEnum.SIGN_TREASURE, SignActivityTypeEnum.SIGN_TREASURE);

        ShareActTypeToActType.put(ShareRelTypeEnum.SIGN_FOR_NEW,SignActivityTypeEnum.SIGN_FOR_NEW);
        for(Map.Entry<SignSourceTypeEnum, SignActivityTypeEnum> entry : sourceToActType.entrySet()){
            actTypeToSource.put(entry.getValue(), entry.getKey());
        }

        actTypeToUniform.put(SignActivityTypeEnum.SIGN_CALENDAR, ActivityUniformityTypeEnum.CalendarSign);
        actTypeToUniform.put(SignActivityTypeEnum.SIGN_CONTRACT, ActivityUniformityTypeEnum.ContractSign);
        actTypeToUniform.put(SignActivityTypeEnum.SIGN_FOR_NEW, ActivityUniformityTypeEnum.SignForNew);
        actTypeToUniform.put(SignActivityTypeEnum.SIGN_TREASURE, ActivityUniformityTypeEnum.SignTreasure);
        actTypeToUniform.put(SignActivityTypeEnum.SIGN_PET,ActivityUniformityTypeEnum.PetSign);
        actTypeToUniform.put(SignActivityTypeEnum.SIGN_WANDER,ActivityUniformityTypeEnum.ManageSign);
        actTypeToUniform.put(SignActivityTypeEnum.SIGN_CALENDAR_COMPONENT,ActivityUniformityTypeEnum.SIGN_CALENDAR_COMPONENT);
    }

    public static SignActivityTypeEnum getSignActType(SignSourceTypeEnum sourceType){
        return sourceToActType.get(sourceType);
    }

    public static SignSourceTypeEnum getSignSource(SignActivityTypeEnum signType){
        return actTypeToSource.get(signType);
    }

    public static ActivityUniformityTypeEnum getUniActType(SignActivityTypeEnum signType){
        return actTypeToUniform.get(signType);
    }

    public static SignActivityTypeEnum getSignActTypeByShareTypeEnum(ShareRelTypeEnum shareRelTypeEnum){
        return ShareActTypeToActType.get(shareRelTypeEnum);
    }
}
